import { parse, GraphQLSchema, ParseOptions, ValidationRule, FragmentDefinitionNode, IntrospectionQuery } from 'graphql';
import type { IPosition } from 'graphql-language-service-types';
import { defaultSchemaLoader, SchemaConfig } from './schemaLoader';
export declare type GraphQLLanguageConfig = {
    parser?: typeof parse;
    jsonParser?: typeof JSON.parse;
    schemaLoader?: typeof defaultSchemaLoader;
    parseOptions?: ParseOptions;
    schemaConfig: SchemaConfig;
    exteralFragmentDefinitions?: FragmentDefinitionNode[] | string;
};
export declare class LanguageService {
    private _parser;
    private _schemaConfig;
    private _schemaLoader;
    private _parseOptions;
    private _exteralFragmentDefinitionNodes;
    private _exteralFragmentDefinitionsString;
    constructor({ parser, schemaLoader, schemaConfig, parseOptions, exteralFragmentDefinitions, }: GraphQLLanguageConfig);
    get schema(): GraphQLSchema | undefined;
    get schemaConfig(): SchemaConfig;
    get introspectionJSON(): IntrospectionQuery;
    getSchema(): Promise<GraphQLSchema | null>;
    getExternalFragmentDefinitions(): Promise<FragmentDefinitionNode[]>;
    setSchema(schema: GraphQLSchema): Promise<void>;
    loadSchema(): Promise<GraphQLSchema | null>;
    parse(text: string, options?: ParseOptions): import("graphql").DocumentNode;
    getCompletion: (_uri: string, documentText: string, position: IPosition) => Promise<import("graphql-language-service-types").CompletionItem[]>;
    getDiagnostics: (_uri: string, documentText: string, customRules?: ValidationRule[] | undefined) => Promise<import("vscode-languageserver-types").Diagnostic[]>;
    getHover: (_uri: string, documentText: string, position: IPosition) => Promise<string | import("vscode-languageserver-types").MarkupContent | {
        language: string;
        value: string;
    } | import("vscode-languageserver-types").MarkedString[]>;
    getVariablesJSONSchema: (_uri: string, documentText: string) => Promise<import("json-schema").JSONSchema6 | null>;
}
//# sourceMappingURL=LanguageService.d.ts.map