"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultSchemaLoader = void 0;
const graphql_1 = require("graphql");
const defaultSchemaLoader = (schemaConfig, parser) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const { requestOpts, uri, introspectionOptions, schema: graphQLSchema, documentAST, introspectionJSON, introspectionJSONString, buildSchemaOptions, documentString, } = schemaConfig;
    if (graphQLSchema) {
        return {
            schema: graphQLSchema,
            documentString: graphql_1.printSchema(graphQLSchema),
        };
    }
    if (introspectionJSON) {
        return {
            schema: graphql_1.buildClientSchema(introspectionJSON, buildSchemaOptions),
            introspectionJSON,
            introspectionJSONString: JSON.stringify(introspectionJSON),
        };
    }
    if (introspectionJSONString) {
        const introspectionJSONResult = JSON.parse(introspectionJSONString);
        return {
            introspectionJSON: introspectionJSONResult,
            schema: graphql_1.buildClientSchema(introspectionJSONResult, buildSchemaOptions),
            introspectionJSONString,
        };
    }
    if (documentAST) {
        const schema = graphql_1.buildASTSchema(documentAST, buildSchemaOptions);
        return {
            schema,
            documentAST,
            documentString: graphql_1.printSchema(schema),
        };
    }
    if (documentString) {
        return {
            schema: graphql_1.buildASTSchema(parser(documentString), buildSchemaOptions),
            documentString,
        };
    }
    if (!uri) {
        return null;
    }
    const fetchResult = yield fetch(uri, Object.assign(Object.assign({ method: (_a = requestOpts === null || requestOpts === void 0 ? void 0 : requestOpts.method) !== null && _a !== void 0 ? _a : 'post', body: JSON.stringify({
            query: graphql_1.getIntrospectionQuery(introspectionOptions),
            operationName: 'IntrospectionQuery',
        }), credentials: 'omit' }, requestOpts), { headers: Object.assign({ 'Content-Type': 'application/json' }, requestOpts === null || requestOpts === void 0 ? void 0 : requestOpts.headers) }));
    const { data } = yield fetchResult.json();
    return {
        schema: graphql_1.buildClientSchema(data, buildSchemaOptions),
        introspectionJSON: data,
        introspectionJSONString: JSON.stringify(data),
    };
});
exports.defaultSchemaLoader = defaultSchemaLoader;
//# sourceMappingURL=schemaLoader.js.map