import { getIntrospectionQuery, buildClientSchema, buildASTSchema, printSchema, } from 'graphql';
export const defaultSchemaLoader = async (schemaConfig, parser) => {
    const { requestOpts, uri, introspectionOptions, schema: graphQLSchema, documentAST, introspectionJSON, introspectionJSONString, buildSchemaOptions, documentString, } = schemaConfig;
    if (graphQLSchema) {
        return {
            schema: graphQLSchema,
            documentString: printSchema(graphQLSchema),
        };
    }
    if (introspectionJSON) {
        return {
            schema: buildClientSchema(introspectionJSON, buildSchemaOptions),
            introspectionJSON,
            introspectionJSONString: JSON.stringify(introspectionJSON),
        };
    }
    if (introspectionJSONString) {
        const introspectionJSONResult = JSON.parse(introspectionJSONString);
        return {
            introspectionJSON: introspectionJSONResult,
            schema: buildClientSchema(introspectionJSONResult, buildSchemaOptions),
            introspectionJSONString,
        };
    }
    if (documentAST) {
        const schema = buildASTSchema(documentAST, buildSchemaOptions);
        return {
            schema,
            documentAST,
            documentString: printSchema(schema),
        };
    }
    if (documentString) {
        return {
            schema: buildASTSchema(parser(documentString), buildSchemaOptions),
            documentString,
        };
    }
    if (!uri) {
        return null;
    }
    const fetchResult = await fetch(uri, {
        method: requestOpts?.method ?? 'post',
        body: JSON.stringify({
            query: getIntrospectionQuery(introspectionOptions),
            operationName: 'IntrospectionQuery',
        }),
        credentials: 'omit',
        ...requestOpts,
        headers: {
            'Content-Type': 'application/json',
            ...requestOpts?.headers,
        },
    });
    const { data } = await fetchResult.json();
    return {
        schema: buildClientSchema(data, buildSchemaOptions),
        introspectionJSON: data,
        introspectionJSONString: JSON.stringify(data),
    };
};
//# sourceMappingURL=schemaLoader.js.map